@@ -37,7 +37,6 @@ char *mimetype;
 
 static XWindowAttributes wattr;
 static Window victim;
-static Window old_parent;
 
 #define MAX_IGNORED 1000
 static int windows_found;
@@ -74,35 +73,28 @@ static void place_window()
      Window parent = WINDOW;
      int w = windata.width;
      int h = windata.height;
+     XWMHints *leader_change;
 
-     D("Old: %x  New:%x\n", old_parent, parent);
+     D("Parent Window: %x\n", parent);
+     D("Victim Window: %x\n", victim);
 
-     if (old_parent != parent)
+     XWithdrawWindow(display, victim, XScreenNumberOfScreen (wattr.screen));
+     XSync(display, FALSE);
+
+     D("Changing leader of window %x\n", victim);
+     if ((leader_change = XGetWMHints(display, victim)))
      {
-	  D("Withdrawing Window %x\n", victim);
-	  XWithdrawWindow(display, victim, XScreenNumberOfScreen (wattr.screen));
+	  leader_change->flags = (leader_change->flags | WindowGroupHint);
+	  leader_change->window_group = wattr.root;
+	  XSetWMHints(display, victim, leader_change);
+	  XFree(leader_change);
+     }
+
+     D("Reparenting window %x into %x\n", victim, parent);
+     for (x = 0; x < 25; x++)
+     {
+	  XReparentWindow(display, victim, parent, 0, 0);
 	  XSync(display, FALSE);
-
-	  if (!old_parent)
-	  {
-	       XWMHints *leader_change;
-	       D("Changing leader of window %x\n", victim);
-	       if ((leader_change = XGetWMHints(display, victim)))
-	       {
-		    leader_change->flags = (leader_change->flags | WindowGroupHint);
-		    leader_change->window_group = wattr.root;
-	
-		    XSetWMHints(display,victim,leader_change);
-		    XFree(leader_change);
-	       }
-	  }
-
-	  D("Reparenting window %x into %x\n", victim, parent);
-	  for (x = 0; x < 25; x++)
-	  {
-	       XReparentWindow(display, victim, parent, 0, 0);
-	       XSync(display, FALSE);
-	  }
      }
 
      XMapWindow(display, victim);
@@ -159,7 +151,7 @@ static Window winrecur(Window from,
 {
      Window root, parent;
      Window *children = NULL;
-     int e, num_children;
+     unsigned int e, num_children;
      Window found = -1;
   
      D("Winrecur, checking window %x (depth=%d)\n", from, depth);
@@ -338,7 +330,6 @@ static int init_swallow()
      D("rootwin=%x\n", wattr.root);
 
      victim = 0;
-     old_parent = 0;
 
      if (flags & H_EVENT_SWALLOW)
      {
@@ -428,21 +419,9 @@ static void handle_app(int pid)
      {
 	  if (got_sigwinch)
 	  {
-	       Window oldwindow = WINDOW;
 	       got_sigwinch = 0;
-	  
-	       D("Got SIGWINCH, new parent=%x\n", WINDOW);
-	  
 	       if (swallow_done)
-	       {
 		    place_window();
-	       }
-	       else if (strstr(command,"$window") && oldwindow != WINDOW)
-	       {
-		    my_kill(pid);
-		    waitpid_done++;
-		    continue;
-	       }
 	  }
 
 	  if (flags & H_EXITS)
