@@ -19,7 +19,6 @@
 
 #include "mozplugger.h"
 
-#define WINDOW ((Window) THIS->windata.window)
 #define THIS (*(data_t **) &(instance->pdata))
 #define FEND(X,Y) (strchr(X,Y)?strchr(X,Y):(X)+strlen(X))
 
@@ -174,7 +173,7 @@ static int inpath(char *path, char *file)
      int i;
      int count = 1;
 
-     for (i = strlen(path); i > 0; i--)
+     for (i = strlen(path)-1; i > 0; i--)
 	  if (path[i] == ':')
 	  {
 	       path[i] = 0;
@@ -742,7 +741,7 @@ NPError NPP_New(NPMIMEType pluginType,
      if (!THIS) return NPERR_OUT_OF_MEMORY_ERROR;
      memset((char *)THIS, 0, sizeof(*THIS));
 
-     WINDOW = 0;
+     THIS->windata.window = 0;
      THIS->display = NULL;
      THIS->displayname = NULL;
      THIS->pid = -1;
@@ -945,8 +944,8 @@ int maximize_child_window(int flags, Display *display, Window *window, int w, in
 {
      Window *useme = NULL;
      Window root, parent;
-     Window *children=NULL;
-     int num_children;
+     Window *children = NULL;
+     unsigned int num_children;
 
      /* tell the child of the stored tree to resize, sadly we don't know
 	the handle of that window, since the helper handles it for us */
